// RyoBat.scad - Model of Ryobi 18v power tool battery
//
// Licence:
//
// Versions:
//			- Basic outlines
//  0-2		- Round INsert
//
////////////////////////////////////////////////////////
//
// Size Variables
//
// Sections: Base (B), Front Block (FB), Insert Support Block (IS), Insert (IN)
// Base Sections: Square in middle, Rear Curved, Front First Taper, Front End Taper, Clips, ...?
// IS Sections  : IS Block(ISB), IS Front Prongs (ISFP)
/*
 *        -------
 *        |     |   <---------------------IN
 *        |     |
 *        |     |   v---------------------IS
 *        |     |_______          v-------FB
 *     ___|             |--_____----___
 *     |                 ^            |             ^
 *     |                  \ISFP       |             |          /
 *     |           (Base)             |    <--X-->  Z         Y
 *     |                              |             |        /
 *     |______________________________|             v
 * 
 */
S=0.05; 		// Smidgen used for difference
//
BH=35; //55.0;		// Base Height ie Z Axis (55mm is the large battery pack, 35mm the small)
BW=75.0;		// " Width     ie Y Axis
BL=131.55;		// " Length    ie X xis
BSL=78.0;		// " Square-section Length ie the middle sq bit in X Axis
BR=45;			// " Radius of rear curve
BFW=50;			// " Front Width 
BFCXO=16;		// " Front Cut X Offset from front

module Base(BH=BH) {
	union() {
		intersection() {
			translate([BR,BW/2,0])
				cylinder(r=BR,h=BH);
			cube([BL/2+S,BW,BH]);
		} // i
		hull() {
			translate([BL/2,0,0])
				cube([BL/2-BFCXO,BW,BH]);
			translate([BL/2+2*S,(BW-BFW)/2,0])
				cube([BL/2-2*S,BFW,BH]);
		} // h
	} // u
} // Base

//
ISXO=22.8;		// Insert Support X Offset (from base)
ISW=61.5;		// " " Width
ISL=55.75;		// " " Length
ISH=8.5;		// " " Height  
ISR=45;			// " " Radius of rear
ISRX=10;		// " " " X spot where curve stops

module ISB() {
	intersection() {
		translate([ISR,ISW/2,0])
			cylinder(r=ISR, h=ISH);
		cube([ISL,ISW,ISH]);
	} // i
} // ISB

//
FBH=2.2;		// FB Height 
FBWR=58;		// " Width Rear 
FBWF=44;		// " " Front
FBLM=23;			// " Length (at middle)
FBLS=14.3;		// " " at Side
FBXO=BL-FBLM-8.6;// FB X Offset (8.6 from right end)

module FB() {
	// start with simple block
	// 2Do taper & curve
	hull() {
		cube([FBLS,FBWR,FBH+S]);
		translate([0,(FBWR-FBWF)/2,0])
			cube([FBLM,FBWF,FBH+S]);
	} // h
} // FB

//
ISFPH=FBH;		// " " Front Prong Height  
ISFPW=10;		// " " " " Width
ISFPL=12.3;		// " " " " Length
ISFPYO=11;		// " " " " Y Offset
ISFPG=19.9;		// " " " Gap between prongs
ISFPYO2=ISFPYO+ISFPW+ISFPG; // Y offset of second prong

module ISFP() {
	cube([ISFPL+S,ISFPW,ISFPH+S]);
} // ISFP

module ISBandISFP() {
	// remember to add S to Z
	union() {
		ISB();
		translate([ISL-S,ISFPYO,0])
			ISFP();					
		translate([ISL-S,ISFPYO2,0])
			ISFP();
	} // u
} // ISBansISFP

//
INXO=0.25;		// Insert X Offset (from IS)
INW=27.6;		// " Width
INL=32.5;			// " Length
INH=44;			// " Height  
INR=13.4;		// " Radius (rear)
INRFC=12;		// " " Front corner
INRFCX=0;		// " " " " X inset
INBRX=8.1;		// " Battery Recess X width (& Y for front)
INSBRXO=8;		// " " " " " Offset from front
INBRI=3;		// " Battery Recess Inset
INBRZ=14.5;		// " " " Z depth

module IN() {
	
	difference() {
		union() {
			translate([INR,0,0]) {
				translate([0,INW/2,0])
					cylinder(h = INH, r=INR);
				cube([INL-INR-INRFC/2-INRFCX,INW,INH]);
				// chamfer front corners & block in middle
				translate([0,INRFC/2,0])
					cube([INL-INR,INW-INRFC,INH]);
				translate([INL-INR-INRFC/2-INRFCX,INRFC/2,0])
					cylinder(r=INRFC/2, h= INH);
				translate([INL-INR-INRFC/2-INRFCX,INW-INRFC/2,0])
					cylinder(r=INRFC/2, h= INH);
			} // t
		} // u
		// side battery recesses
		translate([INL-INBRX-INSBRXO,INW-INBRI,INH-INBRZ])
			cube([INBRX,INBRI+S,INBRZ+S]);
		translate([INL-INBRX-INSBRXO,-S,INH-INBRZ])
			cube([INBRX,INBRI+S,INBRZ+S]);
		// front battery recess - centered
		translate([INL-INBRI,INW/2-INBRX/2,INH-INBRZ])
			cube([INBRI+S,INBRX+S,INBRZ+S]);
	} // d
} // IN
		

module RyoBat() {
	union() {
		Base();
		translate([0,0,BH-S]) {
			translate([ISXO,BW/2-ISW/2,0])
				ISBandISFP();					// remember to add S to Z height  
			translate([FBXO,BW/2-FBWR/2,0])
				FB();							// "
			translate([ISXO+INXO,BW/2-INW/2,ISH])
				IN();							// "
		} // t
	} // u
} // RyoBat

// Make it - uncomment or use other modules below

RyoBat();



// Some quick & dirty help modules - also fiddle with BH value

//AngledBase([0,0,0],0);  // fiddle with last parameter to get thickness right

//AngledBat([0,5,0],-15);

//AngledBatWithHoles(0,0);

module AngledBase(a, hm=1) {
	difference() {
		rotate(a)
			translate([0,0,-BH*hm])
				Base(BH);
		// -
		translate([-BL/2,-BW/2,-BH*2])
			cube([BL*2,BW*2,BH*2]);
	} // d
} // AngledBase

module AngledBat(a,hm=0) {
	difference() {
		rotate(a)
			translate([0,0,hm])
				RyoBat();
		// -
		translate([-BL*1.5,-BW*1.5,-BH*2])
			cube([BL*3,BW*3,BH*2]);
echo(BL,-BL/2,BW,-BW/2,BH,-BH/2);
	} // d
} // AngledBat

module AngledBatWithHoles(a=0,hm=0) {
	HoleDiam=4;
	HoleInsetBack=10;
	HoleInsetFront=FBXO-10;
	difference() {
		AngledBat([0,a,0],hm);
		// -
		rotate([0,a,0]) {
			translate([HoleInsetBack,BW/2,-0.1])
				cylinder(r=HoleDiam/2,h=BH+0.2);
			translate([HoleInsetFront,BW/2,-0.1])
				cylinder(r=HoleDiam/2,h=BH+0.2);
		}
	} // d
} // A B W H
